@@ -1,5 +1,3 @@
-import sys
-
 from tap.formatter import format_as_diagnostics, format_exception
 from tap.tests import TestCase
 
@@ -13,11 +11,7 @@ class TestFormatter(TestCase):
         self.assertEqual(expected_diagnostics, diagnostics)
 
     def test_format_exception_as_diagnostics(self):
-        # Making a tracback intentionally is not straight forward.
-        try:
-            raise ValueError('boom')
-        except ValueError:
-            exc = sys.exc_info()
-            diagnostics = format_exception(exc)
-            self.assertTrue(diagnostics.startswith('# '))
-            self.assertTrue('boom' in diagnostics)
+        exc = self.factory.make_exc()
+        diagnostics = format_exception(exc)
+        self.assertTrue(diagnostics.startswith('# '))
+        self.assertTrue('boom' in diagnostics)
